%
% Here we figure out what the xlim of the section plots.  They
% must be the same.  The origin of each section is where the section
% crosses the baseline.
function d = lateral_distance ( station_lon, station_lat, base_lon, base_lat )

station_lon = station_lon(:);
station_lat = station_lat(:);

n = length(station_lon);

%
% find equation of baseline
m = diff(base_lat)/diff(base_lon);
b = base_lat(1) - m*base_lon(1);


%
% if the first station is below the line, project that station onto the line
% and use that as the first point
if ( station_lat(1) < (m*station_lon(1)+b) )

    [base_lonm, base_latm] = m_ll2xy(base_lon, base_lat);
    [station_lonm, station_latm] = m_ll2xy(station_lon(1), station_lat(1));
    [proj_lonm, proj_latm] = project_onto_baseline ( base_lonm, base_latm, station_lonm,station_latm );
    [proj_lon, proj_lat] = m_xy2ll ( proj_lonm, proj_latm );

    lon = [proj_lon; station_lon(:)];
    lat = [proj_lat; station_lat(:)];

    origin_index = 1;


%
% if the last station is above the line, project that station onto the line
% and use that as the last point
elseif ( station_lat(n) > (m*station_lon(n)+b) )

    [base_lonm, base_latm] = m_ll2xy(base_lon, base_lat);
    [station_lonm, station_latm] = m_ll2xy(station_lon(n), station_lat(n));
    [proj_lonm, proj_latm] = project_onto_baseline ( base_lonm, base_latm, station_lonm,station_latm );
  [proj_lon, proj_lat] = m_xy2ll ( proj_lonm, proj_latm );

    lon = [station_lon(:); proj_lon];
    lat = [station_lat(:); proj_lat];

    origin_index = n+1;


%
% otherwise the baseline intersects the string of stations somewhere in
% the middle.
else

    base_lat = m*station_lon + b;
    inds = find ( station_lat < base_lat );
    i = inds(1);

    %
    % Ok, we've found it, the baseline intersects between station(i)
    % and station(i-1).  Form the equation of the line between
    % those two stations, set the equations of the two lines equal
    % to each other, and solve for the location.
    ms = (station_lat(i) - station_lat(i-1))/(station_lon(i)-station_lon(i-1));
    bs = station_lat(i) - ms*station_lon(i);

    intersect_lon = (bs - b) / (m - ms );
    intersect_lat = ms * intersect_lon + bs;

    station_lon = station_lon(:);
    station_lat = station_lat(:);
    lon = [station_lon(1:i-1); intersect_lon; station_lon(i:n)];
    lat = [station_lat(1:i-1); intersect_lat; station_lat(i:n)];

    origin_index = inds(1);

end






%
% Now find the lateral distance along the string of stations.
% The origin is at the baseline.
d = [0 cumsum(dist(lat,lon))];
d = d - d(origin_index);

d(origin_index) = [];
d = d/1000;


return

