%
% given the baseline formed by line_x and line_y, find the projection of the
% station whos location is [station_x, station_y] onto the line.
%
% Define the first point of line_x and line_y as "P1"
% Define the 2nd point as "P2".
% Define Vb = P2 - P1.
% Define the point [station_x, station_y] as "Ps".
% Define the point of projection as "Pp".
% Define the vector "Vc" = Ps - Pp
% Define the vector "Vw" = P2 - Pp
%
% Then the dot product of Vb and Vc is 0, and the cross product of
% Vw and Vb is 0.  This gives two equations in two unknowns, allowing
% us to solve for the point Pp.
function [projx, projy] = project_onto_baseline ( line_x, line_y, station_x, station_y )

p1x = line_x(1);
p1y = line_y(1);
p2x = line_x(2);
p2y = line_y(2);

Vbx = p2x - p1x;
Vby = p2y - p1y;

psx = station_x;
psy = station_y;

A = [Vbx Vby; Vby  -Vbx];
b = [(Vbx*psx + Vby*psy); (Vby*p2x - Vbx*p2y)];

Pp = A\b;
projx = Pp(1);
projy = Pp(2);


return


