%
% function [out]=sect_xtract(matfile,line,variable)
%
% EXAMPLE  D_sal=sect_xtract('98cb01','D','sal')
%
% This returns a structure which contains the data for the given cruise
% and transect including:
% section_line_variable: the CTD casts for that line and variable
% section_dist: the distance of each of the stations from the baseline
% X: the X for a contour plot (or any other matlab routine)
% Y: the Y for ....
% bathy: this contains a 2-d vector which maps the bottom along the transect
%
%


 function [out]=sect_xtract(matfile,line,variable)

if nargin==0
help sect_xtract
return
end

load(matfile)
% extract the asked-for variable
data = [];
eval ( sprintf ( 'data = cruise.%s;', variable ) );

% get the right line
for i=1:15
	if strcmp(line,cruise.sections.sect{i})==1
	break
	end
end


if i==15
disp('pick a real leg')
return
end

if isempty(cruise.sections.stanum{i})
disp('Sorry, that transect was not sampled on that cruise')
out.flag='error';
return
end

out.descript=[cruise.descript '   '  cruise.sections.sect{i} ' line'];
out.variable=variable;
out.section_data= data(:,cruise.sections.stanum{i});
 out.section_dist = cruise.sections.lateral_dist{i};
 [out.X,out.Y] = meshgrid(out.section_dist, cruise.z);
out.staid=cruise.staid(cruise.sections.stanum{i},:);
out.stanum=cruise.sections.stanum{i};
out.bathy=cruise.sections.bathy{i};
return
