%
% function []=v_contour(sectract,contour_vector,clim_vector)
%
% EXAMPLE  v_contour(D_sal,[26:.5:32],[26 32])
%
% This function draws a vertical profile of a given transect
% and variable which were specified in SECT_XTRACT
% sectract is the output structure from SECT_XTRACT
%
% contour_vector specifies the contouring, clim_vector the colorlimits
%
% The colormap is set to gray, but feel free to get creative.
% 
% You lose the automatic setting of min and max X, but adds alot
% of flexibility.
%
%

function []=v_contour(sectract,contour_vector,clim_vector)

if nargin==0
help v_contour
return
end



sec_plot_figure = figure ( 'Position',  [165 304 1091 652]);

cmap = ((gray(100).*.75)+.25);
[r,c] = size(cmap);
%cmap = cmap(20:80,:);
colormap(cmap);

% flip the colormap if temperature is the variable
if strcmp(sectract.variable,'temp')==1
        colormap(flipud(cmap));
end

% do the contouring
    [c,h2] = contourf ( sectract.X, sectract.Y, sectract.section_data, contour_vector );
    shading flat
    hold on
    [c,h2] = contour ( sectract.X, sectract.Y, sectract.section_data, contour_vector,'k' );
    clabel(c,h2);

% overlay the bottom
fill(sectract.bathy(:,1),sectract.bathy(:,2),[.76 .68 .54])

% label the stations

section_dist = sectract.section_dist;
    station_numbers = sectract.stanum;
    station_ids=sectract.staid;
for j = 1:length(section_dist)
 cast_label = sprintf ( '#%d', station_numbers(j) );
 staid_label = [station_ids(j,:)];
        th(j) = text ( section_dist(j), 0, cast_label, ...
                       'HorizontalAlignment', 'center', ...
                       'VerticalAlignment', 'Baseline', ...
                       'color', [0.2 0.2 0.2], ...
                       'FontSize', 10, ...
                       'Tag', 'station number text' );
 sh(j) = text ( section_dist(j), 2, staid_label, ...
                       'HorizontalAlignment', 'center', ...
                       'VerticalAlignment', 'Baseline', ...
                       'color', [0.2 0.2 0.2], ...
                       'FontSize', 10, ...
                       'Tag', 'station number text' );

end

title ( sprintf ( '%s: %s', sectract.descript, sectract.variable ), ...
        'Tag', 'Section Plot Title' );

% Set some common properties
set ( gca, ...
        'Box', 'on', ...
        'CLim', clim_vector, ...
	'Ylim', [-50 0], ...
        'Layer', 'top', ...
        'Color', [1 1 1]);


%dolandscape


return
