%
% function []=v_dotter(matfile,sectract)
%
% EXAMPLE  v_dotter('98cb01','98_01D_sal')
%
% This function sprinkles the dots over the vertical contours
% If you open the file you can change the limits and colors right at the
% top.
%
%
% matfile: contains the alexandrium data for the dots
%
% sectract: file produced by SECT_XTRACT which contains lateral distances
%   and station numbers
%
%


function []=v_dotter(matfile,sectract)

% This specifies the cutoffs for the cellcount bins
limit1=20;
limit2=50;
limit3=100;
limit4=200;

% This specifies the dotsize
dotsize=20;

% This specifies the color of the dots at each interval
color1='g';
color2='y';
  orange=[1 .5 0];
color3=orange;
  purple=[.5 0 .5];
color4=purple;
color5='r';
label_lim=500;

% These specifies the grid coordinates where the labeling begins and the spacing
% it's in plot coordinates
foo=get(gca);
xlabel=foo.XLim(1)+3;
ylabel=-35;
diff=2;

if nargin==0
help v_dotter
return
end


load(matfile)

section_dist=sectract.section_dist;
station_numbers=sectract.stanum;
for j = 1:length(section_dist)
 hold on
        for down=1:length(cruise.alex)

        if ~isnan(cruise.alex(down,station_numbers(j)))
                cellno=cruise.alex(down,station_numbers(j));
                below=-down/4;
        elseif ~isnan(cruise.alexpooled(station_numbers(j))) & down==14
                cellno=cruise.alexpooled(station_numbers(j));
                below=-3.5;
        else
                cellno=-1;
                below=-1;
        end

        if cellno==-1
                foo=0;
        elseif cellno<=limit1
                 ht=line(section_dist(j),below,'linestyle','none','marker','.','markersize',...
                   dotsize,'color',color1);
        elseif cellno<=limit2
                 ht=line(section_dist(j),below,'linestyle','none','marker','.','markersize',...
                   dotsize,'color',color2);
        elseif cellno<=limit3
                 ht=line(section_dist(j),below,'linestyle','none','marker','.','markersize',...
                 dotsize,'color',color3);
        elseif cellno<=limit4
                 ht=line(section_dist(j),below,'linestyle','none','marker','.','markersize',...
                 dotsize,'color',color4);
        elseif cellno>limit4
                 ht=line(section_dist(j),below,'linestyle','none','marker','.','markersize',...
                 dotsize,'color',color5);
                 if cellno>=label_lim
                 text(section_dist(j),below,sprintf('%5.0f',cellno),...
                       'HorizontalAlignment','center','VerticalAlignment','top','Color',color5)
                 end
        end
        end
    end

    %cell count labeling



htitle=line(xlabel,ylabel,'linestyle','none','marker','.','markersize',...
      dotsize,'color',[.9 .9 .9]);
ltitle='Alexandrium tamarense';
h1=line(xlabel,ylabel,'linestyle','none','marker','.','markersize',...
      dotsize,'color',color1);
label1=[' < ' int2str(limit1) ' cells/liter'];
h2=line(xlabel,ylabel,'linestyle','none','marker','.','markersize',...
    dotsize,'color',color2);
label2=[' 'int2str(limit1) '-' int2str(limit2)];
h3=line(xlabel,ylabel,'linestyle','none','marker','.','markersize',...
     dotsize,'color',color3);
label3=[' ' int2str(limit2) '-' int2str(limit3)];
h4=line(xlabel,ylabel,'linestyle','none','marker','.','markersize',...
  dotsize,'color',color4);
label4=[' ' int2str(limit3) '-' int2str(limit4)];
h5=line(xlabel,ylabel,'linestyle','none','marker','.','markersize',...
  dotsize,'color',color5);
  label5=[' > ' int2str(limit4)];

  leggs=legend([htitle h1 h2 h3 h4 h5],ltitle,label1,label2,label3,label4,label4,label5,3);

  
  set(htitle,'Visible','off')
  set(h1,'Visible','off')
  set(h2,'Visible','off')
  set(h3,'Visible','off')
  set(h4,'Visible','off')
  set(h5,'Visible','off')
set(leggs,'FontSize',[26],'Color',[.9 .9 .9]);


return 
